# ktg
![python_version](https://img.shields.io/static/v1?label=Python&message=3.5%20|%203.6%20|%203.7&color=blue) [![PyPI downloads/month](https://img.shields.io/pypi/dm/ktg?logo=pypi&logoColor=white)](https://pypi.python.org/pypi/ktg)

## Description
send telegram message

## Install
~~~~bash
pip install ktg
# or
pip3 install ktg
~~~~